"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const server_1 = require("./server");
function getForQuery(connectionUrl, query) {
    return __awaiter(this, void 0, void 0, function* () {
        const request = {
            method: 'POST',
            body: JSON.stringify({ connectionUrl, query })
        };
        const response = yield server_1.Server.makeRequest('/jupyterlab-sql/query', request);
        if (!response.ok) {
            return Private.createErrorResponse(response.status);
        }
        const data = yield response.json();
        const validatedData = Private.validateBody(data);
        return validatedData;
    });
}
exports.getForQuery = getForQuery;
var ResponseModel;
(function (ResponseModel) {
    function createError(message) {
        return {
            responseType: 'error',
            responseData: {
                message
            }
        };
    }
    ResponseModel.createError = createError;
    function createNotFoundError() {
        const errorMessage = 'Failed to reach server endpoints. ' +
            'Is the server extension installed correctly?';
        return createError(errorMessage);
    }
    ResponseModel.createNotFoundError = createNotFoundError;
    function match(response, onSuccessWithRows, onSuccessNoRows, onError) {
        if (response.responseType === 'error') {
            return onError(response.responseData);
        }
        else if (response.responseType === 'success') {
            const responseData = response.responseData;
            if (responseData.hasRows) {
                const { keys, rows } = responseData;
                return onSuccessWithRows(keys, rows);
            }
            else {
                return onSuccessNoRows();
            }
        }
    }
    ResponseModel.match = match;
})(ResponseModel = exports.ResponseModel || (exports.ResponseModel = {}));
var Private;
(function (Private) {
    function createErrorResponse(responseStatus) {
        if (responseStatus === 404) {
            return ResponseModel.createNotFoundError();
        }
        else {
            const errorMessage = 'Unexpected response status from server';
            return ResponseModel.createError(errorMessage);
        }
    }
    Private.createErrorResponse = createErrorResponse;
    function validateBody(responseBody) {
        return responseBody;
    }
    Private.validateBody = validateBody;
})(Private || (Private = {}));
