"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const widgets_1 = require("@phosphor/widgets");
const commands_1 = require("@phosphor/commands");
const Table_1 = require("./Table");
var CommandIds;
(function (CommandIds) {
    CommandIds.copyToClipboard = 'copy-selection-to-clipboard';
})(CommandIds || (CommandIds = {}));
class ResultsTable {
    constructor(keys, data) {
        this._isDisposed = false;
        const contextMenu = this._createContextMenu();
        this._table = Table_1.Table.fromKeysRows(keys, data, { contextMenu });
    }
    get widget() {
        return this._table.widget;
    }
    dispose() {
        this._table.dispose();
        this._isDisposed = true;
    }
    get isDisposed() {
        return this._isDisposed;
    }
    _createContextMenu() {
        const commands = new commands_1.CommandRegistry();
        commands.addCommand(CommandIds.copyToClipboard, {
            label: 'Copy cell',
            iconClass: 'jp-MaterialIcon jp-CopyIcon',
            execute: () => this._copySelectionToClipboard()
        });
        const menu = new widgets_1.Menu({ commands });
        menu.addItem({ command: CommandIds.copyToClipboard });
        return menu;
    }
    _copySelectionToClipboard() {
        const selectionValue = this._table.selectionValue;
        if (selectionValue !== null) {
            apputils_1.Clipboard.copyToSystem(selectionValue);
        }
    }
}
exports.ResultsTable = ResultsTable;
