"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const uuid = require("uuid");
const application_1 = require("@jupyterlab/application");
const apputils_1 = require("@jupyterlab/apputils");
const codeeditor_1 = require("@jupyterlab/codeeditor");
const launcher_1 = require("@jupyterlab/launcher");
const widget_1 = require("./widget");
const tracker_1 = require("./tracker");
const page_1 = require("./page");
require("../style/index.css");
function activate(app, palette, launcher, editorServices, restorer) {
    const tracker = tracker_1.createTracker();
    const command = 'jupyterlab-sql:open';
    restorer.restore(tracker, {
        command,
        args: widget => ({
            initialWidgetName: widget.name,
            initialPageName: widget.pageName,
            initialConnectionUrl: widget.connectionUrl,
            initialTableName: widget.tableName,
            initialSqlStatement: widget.sqlStatement
        }),
        name: widget => widget.name
    });
    app.commands.addCommand(command, {
        label: ({ isPalette }) => (isPalette ? 'New SQL session' : 'SQL'),
        iconClass: 'p-Sql-DatabaseIcon',
        execute: ({ initialWidgetName, initialPageName, initialConnectionUrl, initialTableName, initialSqlStatement }) => {
            const name = (initialWidgetName || uuid.v4());
            const pageName = (initialPageName || page_1.PageName.Connection);
            const connectionUrl = ((initialConnectionUrl || 'postgres://localhost:5432/postgres'));
            const tableName = (initialTableName || '');
            const sqlStatement = (initialSqlStatement || '');
            const widget = new widget_1.JupyterLabSqlWidget(editorServices.factoryService, {
                name,
                pageName,
                connectionUrl,
                tableName,
                sqlStatement
            });
            app.shell.addToMainArea(widget);
            tracker.add(widget);
        }
    });
    palette.addItem({ command, category: 'SQL', args: { isPalette: true } });
    if (launcher) {
        launcher.add({ command, category: 'Other' });
    }
}
/**
 * Initialization data for the jupyterlab-sql extension.
 */
const extension = {
    id: 'jupyterlab-sql',
    autoStart: true,
    requires: [apputils_1.ICommandPalette, launcher_1.ILauncher, codeeditor_1.IEditorServices, application_1.ILayoutRestorer],
    activate
};
exports.default = extension;
