"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const widgets_1 = require("@phosphor/widgets");
const disposable_1 = require("@phosphor/disposable");
const components_1 = require("../components");
const Api = require("../api");
const page_1 = require("../page");
const services_1 = require("../services");
const toolbar_1 = require("./toolbar");
class TableSummaryPage {
    constructor(options) {
        this.pageName = page_1.PageName.TableSummary;
        this._onRefresh = this._onRefresh.bind(this);
        this._content = new Content(options);
        this._toolbar = new toolbar_1.TableSummaryToolbar(options.connectionUrl, options.tableName);
        this._navigateBack = services_1.proxyFor(this._toolbar.backButtonClicked, this);
        this._toolbar.refreshButtonClicked.connect(this._onRefresh);
        this._disposables = disposable_1.DisposableSet.from([this._content, this._toolbar]);
        this._onRefresh();
    }
    get content() {
        return this._content;
    }
    get toolbar() {
        return this._toolbar;
    }
    get navigateBack() {
        return this._navigateBack;
    }
    get isDisposed() {
        return this._disposables.isDisposed;
    }
    dispose() {
        return this._disposables.dispose();
    }
    _onRefresh() {
        return __awaiter(this, void 0, void 0, function* () {
            this._toolbar.setLoading(true);
            yield this._content.refresh();
            this._toolbar.setLoading(false);
        });
    }
}
exports.TableSummaryPage = TableSummaryPage;
class Content extends widgets_1.BoxPanel {
    constructor(options) {
        super();
        this._connectionUrl = options.connectionUrl;
        this._tableName = options.tableName;
        this._responseWidget = new ResponseWidget();
        this.addWidget(this._responseWidget);
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield Api.getTableStructure(this._connectionUrl, this._tableName);
            this._responseWidget.setResponse(response);
        });
    }
}
class ResponseWidget extends components_1.SingletonPanel {
    constructor() {
        super(...arguments);
        this._table = null;
    }
    dispose() {
        this._disposeTable();
        super.dispose();
    }
    setResponse(response) {
        this._disposeTable();
        Api.TableStructureResponse.match(response, (keys, rows) => {
            this._table = new components_1.ResultsTable(keys, rows);
            this.widget = this._table.widget;
        }, ({ message }) => {
            this.widget = new components_1.PreWidget(message);
        });
    }
    _disposeTable() {
        if (this._table) {
            this._table.dispose();
        }
        this._table = null;
    }
}
