"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const signaling_1 = require("@phosphor/signaling");
const components_1 = require("../components");
class TableSummaryToolbar extends apputils_1.Toolbar {
    constructor(connectionUrl, tableName) {
        super();
        this._loadingIcon = new components_1.ToolbarItems.LoadingIcon();
        this._backButtonClicked = new signaling_1.Signal(this);
        this._refreshButtonClicked = new signaling_1.Signal(this);
        this._onBackButtonClicked = this._onBackButtonClicked.bind(this);
        this._onRefreshButtonClicked = this._onRefreshButtonClicked.bind(this);
        this.addItem('back', new components_1.ToolbarItems.BackButton({ onClick: this._onBackButtonClicked }));
        this.addItem('refresh', new components_1.ToolbarItems.RefreshButton({ onClick: this._onRefreshButtonClicked }));
        this.addItem('spacer', apputils_1.Toolbar.createSpacerItem());
        this.addItem('url', new components_1.ToolbarItems.ConnectionUrlItem(connectionUrl));
        this.addItem('table', new components_1.ToolbarItems.TextItem(` ❯ ${tableName}`));
        this.addItem('loading', this._loadingIcon);
    }
    get backButtonClicked() {
        return this._backButtonClicked;
    }
    get refreshButtonClicked() {
        return this._refreshButtonClicked;
    }
    setLoading(isLoading) {
        this._loadingIcon.setLoading(isLoading);
    }
    _onBackButtonClicked() {
        this._backButtonClicked.emit(void 0);
    }
    _onRefreshButtonClicked() {
        this._refreshButtonClicked.emit(void 0);
    }
}
exports.TableSummaryToolbar = TableSummaryToolbar;
